@@ -21,7 +21,6 @@ setMethod(f="as.matrix",
           signature=signature(x="AbstractMassObject"),
           definition=function(x, index) {
 
-  return(matrix(c(x@mass[index], x@intensity[index]), ncol=2L, byrow=FALSE,
-                dimnames=list(NULL, c("mass", "intensity"))))
+  matrix(c(x@mass[index], x@intensity[index]), ncol=2L, byrow=FALSE,
+         dimnames=list(NULL, c("mass", "intensity")))
 })
-
