@@ -19,9 +19,9 @@
 ## AbstractMassObject
 setMethod(f="intensity",
           signature=signature(object="AbstractMassObject"),
-          definition=function(object) {
+          definition=function(object, ...) {
 
-  return(object@intensity)
+  object@intensity
 })
 
 ## AbstractMassObject
@@ -36,6 +36,5 @@ setReplaceMethod(f="intensity",
     stop("Lengths of intensity(", length(object@intensity),
          ") and value (", length(value), ") have to be equal.")
   }
-  return(object)
+  object
 })
-
