@@ -29,6 +29,5 @@
   d <- diff(x)
   d <- d[-1L] < head(d, -1L)
 
-  return(mean(d))
+  mean(d)
 }
-
