@@ -21,18 +21,14 @@
     return(FALSE)
   }
 
-  areFunctions <- length(x) &&
-                  all(.unlist(vapply(x, is.function, logical(1))))
-  return(areFunctions)
+  length(x) && all(.unlist(vapply(x, is.function, logical(1L))))
 }
 
 .stopIfNotIsFunctionList <- function(x) {
   if (!.isFunctionList(x)) {
-    parentCall <- deparse(sys.call(-1))
+    parentCall <- deparse(sys.call(-1L))
     stop(parentCall, " : ", sQuote(deparse(substitute(x))),
          " is no list of functions!", call.=FALSE)
-    return(FALSE)
   }
-  return(TRUE)
+  TRUE
 }
-
